==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkGenericClip.java <==
// java wrapper for vtkGenericClip object
//

package vtk;
import vtk.*;

public class vtkGenericClip extends vtkUnstructuredGridAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetValue_2(double id0);
  public void SetValue(double id0)
    { SetValue_2(id0); }

  private native double GetValue_3();
  public double GetValue()
    { return GetValue_3(); }

  private native void SetInsideOut_4(int id0);
  public void SetInsideOut(int id0)
    { SetInsideOut_4(id0); }

  private native int GetInsideOut_5();
  public int GetInsideOut()
    { return GetInsideOut_5(); }

  private native void InsideOutOn_6();
  public void InsideOutOn()
    { InsideOutOn_6(); }

  private native void InsideOutOff_7();
  public void InsideOutOff()
    { InsideOutOff_7(); }

  private native void SetClipFunction_8(vtkImplicitFunction id0);
  public void SetClipFunction(vtkImplicitFunction id0)
    { SetClipFunction_8(id0); }

  private native long GetClipFunction_9();
  public vtkImplicitFunction GetClipFunction() {
    long temp = GetClipFunction_9();

    if (temp == 0) return null;
    return (vtkImplicitFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetGenerateClipScalars_10(int id0);
  public void SetGenerateClipScalars(int id0)
    { SetGenerateClipScalars_10(id0); }

  private native int GetGenerateClipScalars_11();
  public int GetGenerateClipScalars()
    { return GetGenerateClipScalars_11(); }

  private native void GenerateClipScalarsOn_12();
  public void GenerateClipScalarsOn()
    { GenerateClipScalarsOn_12(); }

  private native void GenerateClipScalarsOff_13();
  public void GenerateClipScalarsOff()
    { GenerateClipScalarsOff_13(); }

  private native void SetGenerateClippedOutput_14(int id0);
  public void SetGenerateClippedOutput(int id0)
    { SetGenerateClippedOutput_14(id0); }

  private native int GetGenerateClippedOutput_15();
  public int GetGenerateClippedOutput()
    { return GetGenerateClippedOutput_15(); }

  private native void GenerateClippedOutputOn_16();
  public void GenerateClippedOutputOn()
    { GenerateClippedOutputOn_16(); }

  private native void GenerateClippedOutputOff_17();
  public void GenerateClippedOutputOff()
    { GenerateClippedOutputOff_17(); }

  private native void SetMergeTolerance_18(double id0);
  public void SetMergeTolerance(double id0)
    { SetMergeTolerance_18(id0); }

  private native double GetMergeToleranceMinValue_19();
  public double GetMergeToleranceMinValue()
    { return GetMergeToleranceMinValue_19(); }

  private native double GetMergeToleranceMaxValue_20();
  public double GetMergeToleranceMaxValue()
    { return GetMergeToleranceMaxValue_20(); }

  private native double GetMergeTolerance_21();
  public double GetMergeTolerance()
    { return GetMergeTolerance_21(); }

  private native long GetClippedOutput_22();
  public vtkUnstructuredGrid GetClippedOutput() {
    long temp = GetClippedOutput_22();

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfOutputs_23();
  public int GetNumberOfOutputs()
    { return GetNumberOfOutputs_23(); }

  private native void SetLocator_24(vtkIncrementalPointLocator id0);
  public void SetLocator(vtkIncrementalPointLocator id0)
    { SetLocator_24(id0); }

  private native long GetLocator_25();
  public vtkIncrementalPointLocator GetLocator() {
    long temp = GetLocator_25();

    if (temp == 0) return null;
    return (vtkIncrementalPointLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateDefaultLocator_26();
  public void CreateDefaultLocator()
    { CreateDefaultLocator_26(); }

  private native int GetMTime_27();
  public int GetMTime()
    { return GetMTime_27(); }

  private native String GetInputScalarsSelection_28();
  public String GetInputScalarsSelection()
    { return GetInputScalarsSelection_28(); }

  private native void SelectInputScalars_29(String id0);
  public void SelectInputScalars(String id0)
    { SelectInputScalars_29(id0); }

  public vtkGenericClip() { super(); }

  public vtkGenericClip(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv7h.pkg.tar.xz: vtk/vtkGenericClip.java <==
// java wrapper for vtkGenericClip object
//

package vtk;
import vtk.*;

public class vtkGenericClip extends vtkUnstructuredGridAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetValue_2(double id0);
  public void SetValue(double id0)
    { SetValue_2(id0); }

  private native double GetValue_3();
  public double GetValue()
    { return GetValue_3(); }

  private native void SetInsideOut_4(int id0);
  public void SetInsideOut(int id0)
    { SetInsideOut_4(id0); }

  private native int GetInsideOut_5();
  public int GetInsideOut()
    { return GetInsideOut_5(); }

  private native void InsideOutOn_6();
  public void InsideOutOn()
    { InsideOutOn_6(); }

  private native void InsideOutOff_7();
  public void InsideOutOff()
    { InsideOutOff_7(); }

  private native void SetClipFunction_8(vtkImplicitFunction id0);
  public void SetClipFunction(vtkImplicitFunction id0)
    { SetClipFunction_8(id0); }

  private native long GetClipFunction_9();
  public vtkImplicitFunction GetClipFunction() {
    long temp = GetClipFunction_9();

    if (temp == 0) return null;
    return (vtkImplicitFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetGenerateClipScalars_10(int id0);
  public void SetGenerateClipScalars(int id0)
    { SetGenerateClipScalars_10(id0); }

  private native int GetGenerateClipScalars_11();
  public int GetGenerateClipScalars()
    { return GetGenerateClipScalars_11(); }

  private native void GenerateClipScalarsOn_12();
  public void GenerateClipScalarsOn()
    { GenerateClipScalarsOn_12(); }

  private native void GenerateClipScalarsOff_13();
  public void GenerateClipScalarsOff()
    { GenerateClipScalarsOff_13(); }

  private native void SetGenerateClippedOutput_14(int id0);
  public void SetGenerateClippedOutput(int id0)
    { SetGenerateClippedOutput_14(id0); }

  private native int GetGenerateClippedOutput_15();
  public int GetGenerateClippedOutput()
    { return GetGenerateClippedOutput_15(); }

  private native void GenerateClippedOutputOn_16();
  public void GenerateClippedOutputOn()
    { GenerateClippedOutputOn_16(); }

  private native void GenerateClippedOutputOff_17();
  public void GenerateClippedOutputOff()
    { GenerateClippedOutputOff_17(); }

  private native void SetMergeTolerance_18(double id0);
  public void SetMergeTolerance(double id0)
    { SetMergeTolerance_18(id0); }

  private native double GetMergeToleranceMinValue_19();
  public double GetMergeToleranceMinValue()
    { return GetMergeToleranceMinValue_19(); }

  private native double GetMergeToleranceMaxValue_20();
  public double GetMergeToleranceMaxValue()
    { return GetMergeToleranceMaxValue_20(); }

  private native double GetMergeTolerance_21();
  public double GetMergeTolerance()
    { return GetMergeTolerance_21(); }

  private native long GetClippedOutput_22();
  public vtkUnstructuredGrid GetClippedOutput() {
    long temp = GetClippedOutput_22();

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfOutputs_23();
  public int GetNumberOfOutputs()
    { return GetNumberOfOutputs_23(); }

  private native void SetLocator_24(vtkIncrementalPointLocator id0);
  public void SetLocator(vtkIncrementalPointLocator id0)
    { SetLocator_24(id0); }

  private native long GetLocator_25();
  public vtkIncrementalPointLocator GetLocator() {
    long temp = GetLocator_25();

    if (temp == 0) return null;
    return (vtkIncrementalPointLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateDefaultLocator_26();
  public void CreateDefaultLocator()
    { CreateDefaultLocator_26(); }

  private native int GetMTime_27();
  public int GetMTime()
    { return GetMTime_27(); }

  private native String GetInputScalarsSelection_28();
  public String GetInputScalarsSelection()
    { return GetInputScalarsSelection_28(); }

  private native void SelectInputScalars_29(String id0);
  public void SelectInputScalars(String id0)
    { SelectInputScalars_29(id0); }

  public vtkGenericClip() { super(); }

  public vtkGenericClip(long id) { super(id); }
  public native long   VTKInit();

}
